/// <reference types="react" />
export declare type OGPVideo = {
    actor: string;
    actorRole: string;
    director: string;
    writer: string;
    duration: string;
    releaseDate: string;
    tag: string;
    series?: string;
};
export declare type OGPSong = {
    duration: string;
    album: string;
    albumDisc: string;
    albumTrack: string;
    musician: string;
};
export declare type OGPAlbum = {
    song: string;
    songDisc: string;
    songTrack: string;
    musician: string;
    releaseDate: string;
};
export declare type OGPPlaylist = {
    song: string;
    songDisc: string;
    songTrack: string;
    creator: string;
};
export declare type OGPMedia = {
    width: number;
    height: number;
    alt: string;
    url: string;
    type?: string;
};
export declare type OGPBook = {
    author: string;
    isbn: string;
    releaseDate: string;
    tag: string;
};
export declare type OGPProfile = {
    firstName: string;
    lastName: string;
    username: string;
    gender: 'male' | 'female';
};
export interface OGPProps {
    image?: string | OGPMedia;
    title: string;
    description: string;
    siteName: string;
    locale?: string;
    url: string;
    type?: 'website' | 'article' | 'book' | 'music.song' | 'music.album' | 'music.playlist' | 'music.radio_station' | 'video.movie' | 'video.episode' | 'video.tv_show' | 'video.other' | 'profile';
    audio?: string;
    video?: string | OGPMedia;
    movie?: OGPVideo;
    song?: OGPSong;
    album?: OGPAlbum;
    playlist?: OGPPlaylist;
    radioStation?: string;
    book?: OGPBook;
    profile?: OGPProfile;
}
/**
 * React OpenGraph component
 * @example
 *
 * ```ts
    import React from 'react'
    import { OGP } from 'react-ogp'
    import Head from 'next/head'

    export default function Index() {
      return (
        <>
          <Head>
            <OGP
              url="https://example.com"
              title="My website"
              description="This is my website"
              siteName="example.com"
              image="http://example.com/cover.jpg"
            />
          </Head>
        </>
      )
    }
 * ```
 */
export declare const OGP: ({ locale, title, siteName, url, type, image, audio, video, movie, description, song, album, playlist, radioStation, book, profile }: OGPProps) => JSX.Element;
